/*
 * Copyright (c) 2020  Jinan Bosai Network Technology Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "cmsis_os2.h"
#include "ohos_init.h"
#include "WATHER.h"


#define TASK_STACK_SIZE 1024 * 8
#define TASK_PRIO 25

BMP280_HandleTypedef bmp280;
float pressure, temperature, asl,humidity;

static void ExampleTask(void)
{
    uint16_t dht_temperature;
	uint16_t dht_humidity;
    BoardInit();

    bmp280_init_default_params(&bmp280.params);
    	while (!bmp280_init(&bmp280, &bmp280.params)) {
		printf("BMP280 initialization failed\n");
	}
    DHT21_Init();
    while (1)
    {
        printf("=======================================\r\n");
        printf("*************A07_WATHER_example***********\r\n");
        printf("=======================================\r\n");
        DHT21_onewire(&dht_temperature,&dht_humidity);
		humidity = (float)dht_humidity/10;
        if(humidity>80){
            BeepStatusSet(ON);
        }
        else{
            BeepStatusSet(OFF);
        }
		// printf("temperature=%d \r\n",dht_temperature);
		// printf("humidity=%d %%\r\n",dht_humidity);

        //读取温度、气压、海拔数据，学员自行补充
        while (!bmp280_read_float(&bmp280, &temperature, &pressure, &asl)) {
            printf("Temperature/pressure reading failed\n");
        }
        printf("Temperature: %.2f C\r\nHumidity: %.2f %%\r\nPressure: %.2f hPa\r\nAltiude: %.2f m\r\n",temperature,humidity, pressure,asl);

        sleep(3);
    }
}

static void ExampleEntry(void)
{
    osThreadAttr_t attr;

    attr.name = "ExampleTask";
    attr.attr_bits = 0U;
    attr.cb_mem = NULL;
    attr.cb_size = 0U;
    attr.stack_mem = NULL;
    attr.stack_size = TASK_STACK_SIZE;
    attr.priority = TASK_PRIO;

    if (osThreadNew((osThreadFunc_t)ExampleTask, NULL, &attr) == NULL) {
        printf("Failed to create ExampleTask!\n");
    }
}

APP_FEATURE_INIT(ExampleEntry);