#include "dht21.h"
#include "hi_time.h"


static void SDA_Output(void)
{
    IoTGpioInit(DHT11_DQ_GPIO);
    IoTGpioSetFunc(DHT11_DQ_GPIO, IOT_GPIO_FUNC_GPIO_13_GPIO);
    IoTGpioSetDir(DHT11_DQ_GPIO, IOT_GPIO_DIR_OUT); // 设置为输出模式
}

static void SDA_Input(void)
{
    IoTGpioInit(DHT11_DQ_GPIO);
    IoTGpioSetFunc(DHT11_DQ_GPIO, IOT_GPIO_FUNC_GPIO_13_GPIO);
    IoTGpioSetDir(DHT11_DQ_GPIO, IOT_GPIO_DIR_IN); // 设置为输入模式

}

static uint8_t Get_SDA(void)
{
	IotGpioValue temp = {0};
    IoTGpioGetInputVal(DHT11_DQ_GPIO,&temp);
    return temp;
}

static void DQ_Rst(void)
{
	SDA_Output();
	hi_udelay(5); 
	DHT11_DQ_OUT_OFF;
	hi_udelay(480);; 
	DHT11_DQ_OUT_ON; 
	hi_udelay(8); 
}

static uint8_t DQ_Presence(void)
{
	uint8_t pulse_time = 0;
	SDA_Input();
	hi_udelay(5); 
	while(Get_SDA() && pulse_time<100 ) 
	{
		pulse_time++;
		hi_udelay(10);//>6us
	}
	if( pulse_time >=20 )
		return 0x01;
	else
		pulse_time = 0;
	while((Get_SDA()==0) && (pulse_time<240 )) 
	{
		pulse_time++;
		hi_udelay(5);//1~5us
	}
	if( pulse_time >=10 )
	{
		return 0x01;
	}
		else
	return 0x0;
}


//拉低最少1us 后延时一小段时间如6us，后再15us内读取完。 后延时45us以上 即一个周期是60us 
//tINIT+tRC+tSample < 15us
//tINIT+tRC+tSample+tDelay>60us

static uint8_t DQ_Read_Bit(void)
{
	uint8_t dat;
	SDA_Output();
	DHT11_DQ_OUT_OFF
	hi_udelay(5); //tINIT>1us 典型5us <15us 
	DHT11_DQ_OUT_ON
	SDA_Input();
	hi_udelay(5);//tRC  典型5us 
	if(Get_SDA())//tSample
		dat = 1;
	else
		dat = 0;
	hi_udelay(70);//tDelay >60us 确保一帧数据传输完毕
	return dat;
}

static uint8_t DQ_Read_Byte(void)
{
	uint8_t i, j, dat = 0;
	for(i=0; i<8; i++)
	{
		j = DQ_Read_Bit();
		dat = (dat) | (j<<i);
	}
	return dat;
}	
	
static void DQ_Write_Byte(uint8_t dat)
{
	uint8_t i, testb;
	SDA_Output();
	for( i=0; i<8; i++ )
	{
		testb = dat&0x01;
		dat = dat>>1;
		if(testb)//写1
		{
			DHT11_DQ_OUT_OFF
			hi_udelay(5);//>1us <15us
			DHT11_DQ_OUT_ON
			hi_udelay(70);//>=60us
		}
		else//写0
		{
			DHT11_DQ_OUT_OFF
			hi_udelay(70);//MY_hi_udelay(70);>60us
			DHT11_DQ_OUT_ON
			hi_udelay(5);//???? 5us	
		}
	}
}	


static uint8_t CRC8MHT_Cal(uint8_t *serial, uint8_t length)
{
	uint8_t result = 0x00;
	uint8_t pDataBuf;
	uint8_t i;
	while(length--) 
	{	
		pDataBuf = *serial++;
		for(i=0; i<8; i++) 
		{
			if((result^(pDataBuf))&0x01)
			{
				result ^= 0x18;
				result >>= 1;
				result |= 0x80;
			}
			else 
			{
				result >>= 1;
			}
			pDataBuf >>= 1;
		}
	}
return result;
}

static uint16_t OwHumA,OwHumB;

//初始化，获取校准数据A B值
void DHT21_Init()
{
	uint8_t i,crc;
	uint8_t ResDat[13];
	
	//Timer4Stop(); 	
	DQ_Rst();
	DQ_Presence();
	DQ_Write_Byte(0xcc);
	DQ_Write_Byte(0xdd);
	
/*	OwHumA = DQ_Read_Byte();
	OwHumA = (OwHumA<<8)|DQ_Read_Byte();
	OwHumB = DQ_Read_Byte();
	OwHumB = (OwHumB<<8)|DQ_Read_Byte();
	*/		
	//Timer4Start();
//当读取满一组数据即 13 个字节后，才有 CRC 值
//无需要时可以按上面读取前面 4 个即可
	
    for(i=0;i<13;i++)
    {
        ResDat[i] = DQ_Read_Byte();
    }
    crc = CRC8MHT_Cal(ResDat,13);
    if(crc == 0)
    {
        OwHumA = ResDat[0];
        OwHumA = (OwHumA<<8)|ResDat[1];
        OwHumB = ResDat[2];
        OwHumB = (OwHumB<<8)|ResDat[3];
    }

}




//读取温湿度函数
uint8_t DHT21_onewire(uint16_t *tem,uint16_t *hum)
	{
		uint8_t ResDat[5],crc=0;
		uint16_t TemBuf;
		uint16_t CapBuf;

 
        DQ_Rst();   
        DQ_Presence();
        DQ_Write_Byte(0xcc);
        DQ_Write_Byte(0x10);
        osDelay(3);	

        DQ_Rst();
        DQ_Presence();
        DQ_Write_Byte(0xcc);
        DQ_Write_Byte(0xbd);
        ResDat[0] = DQ_Read_Byte();
        ResDat[1] = DQ_Read_Byte();
        ResDat[2] = DQ_Read_Byte();
        ResDat[3] = DQ_Read_Byte();
        ResDat[4] = DQ_Read_Byte();


		crc = CRC8MHT_Cal(ResDat,5);
		if(crc == 0)
		{
			TemBuf = (uint16_t)ResDat[1]<<8|(ResDat[0]);
			TemBuf = 40+TemBuf/256;  //*10  结果*10倍 286即28.6℃；
			*tem = TemBuf;
			
			CapBuf = (uint16_t)ResDat[3]<<8|(ResDat[2]);
			CapBuf = (CapBuf-OwHumB)*600/(OwHumA-OwHumB)+300;//同样结果*10
			//20℃为5个湿度点  即1℃为0.25个湿度点  0.1℃为0.025
			CapBuf = CapBuf+ 2.5*(TemBuf-250)/10;
			if(CapBuf>999)CapBuf = 999;
			else if(CapBuf<0)CapBuf=0;
			*hum = (uint16_t)CapBuf;
		}
	return crc;
}














