#include "flame.h"
#include "iot_adc.h"
#include "iot_errno.h"
#include "iot_gpio.h"
#include "iot_gpio_ex.h"

#define WIFI_IOT_IO_NAME_GPIO_8 8
#define WIFI_IOT_IO_NAME_GPIO_14 14

#define OUT_GPIO 7



void FlameInit(void)
{   
    IoTGpioInit(OUT_GPIO);
    IoTGpioSetFunc(OUT_GPIO, IOT_GPIO_FUNC_GPIO_7_GPIO);
    IoTGpioSetDir(OUT_GPIO, IOT_GPIO_DIR_IN); // 设置GPIO_8为输出模式

    // IoTGpioInit(13);
    // IoTGpioSetFunc(13, IOT_GPIO_FUNC_GPIO_13_GPIO);
    // IoTGpioSetDir(13, IOT_GPIO_DIR_IN); // 设置GPIO_8为输出模式

    IoTGpioInit(WIFI_IOT_IO_NAME_GPIO_14);
    IoTGpioSetFunc(WIFI_IOT_IO_NAME_GPIO_14, IOT_GPIO_FUNC_GPIO_14_GPIO);
    IoTGpioSetDir(WIFI_IOT_IO_NAME_GPIO_14, IOT_GPIO_DIR_OUT);

    IoTGpioInit(WIFI_IOT_IO_NAME_GPIO_8);
    IoTGpioSetFunc(WIFI_IOT_IO_NAME_GPIO_8, IOT_GPIO_FUNC_GPIO_8_GPIO);
    IoTGpioSetDir(WIFI_IOT_IO_NAME_GPIO_8, IOT_GPIO_DIR_OUT);
}

/***************************************************************
* 函数名称: GetVoltage
* 说    明: 获取电压值函数
* 参    数: 无
*								
* 返 回 值: 无
***************************************************************/
float GetVoltage(void)
{
    unsigned int ret;
    unsigned short data;

    ret = IoTAdcRead(6, &data, IOT_ADC_EQU_MODEL_8, IOT_ADC_CUR_BAIS_DEFAULT, 0xff);
    if (ret != IOT_SUCCESS)
    {
        printf("ADC Read Fail\n");
    }
    return (float)data * 1.8 * 4 / 4096.0;
}

/***************************************************************
* 函数名称: FlameReadData
* 说    明: 读取数据
* 参    数: 无
* 返 回 值: 无
***************************************************************/
uint8_t FlameReadData(void)
{
    IotGpioValue temp = {0};
    IoTGpioGetInputVal(OUT_GPIO,&temp);
    return temp;
}


/***************************************************************
 * 函数名称: BeepStatusSet
 * 说    明: Beep状态设置
 * 参    数: status,ENUM枚举的数据
 *									OFF,关
 *									ON,开
 * 返 回 值: 无
 ***************************************************************/
void BeepStatusSet(SwitchStatus status)
{
    if (status == ON) {
        IoTGpioSetOutputVal(WIFI_IOT_IO_NAME_GPIO_8, 1); // 设置GPIO_7输出高电平点亮灯
    }
    if (status == OFF) {
        IoTGpioSetOutputVal(WIFI_IOT_IO_NAME_GPIO_8, 0); // 设置GPIO_7输出低电平关闭灯
    }
}

/***************************************************************
 * 函数名称: LedWarnStatusSet
 * 说    明: LED_Warn状态设置
 * 参    数: status,ENUM枚举的数据
 *									OFF,关
 *									ON,开
 * 返 回 值: 无
 ***************************************************************/
void LedWarnStatusSet(SwitchStatus status)
{
    if (status == ON) {
        IoTGpioSetOutputVal(WIFI_IOT_IO_NAME_GPIO_14, 1); // 设置GPIO_14输出高电平点亮灯
    }

    if (status == OFF) {
        IoTGpioSetOutputVal(WIFI_IOT_IO_NAME_GPIO_14, 0); // 设置GPIO_14输出低电平关闭灯
    }
}

