/*
 * Copyright (c) 2022 Jinan Bosai Network Technology Co., LTD Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "DOOR.h"
#include "cmsis_os2.h"
#include "ohos_init.h"
#include "iot_gpio.h"
#include "iot_gpio_ex.h"

#include "hi_time.h"


#define TASK_STACK_SIZE 1024 * 8
#define TASK_PRIO 25


#define GPIO_0 10
#define GPIO_1 12

float GetDistance  (void) {
    static unsigned long start_time = 0, time = 0;
    float distance = 0.0;
    IotGpioValue value = IOT_GPIO_VALUE0;
    unsigned int flag = 0;
    IoTWatchDogDisable();

    // hi_io_set_func(GPIO_8, GPIO_FUNC);
    IoTGpioInit(GPIO_0);
    IoTGpioSetFunc(GPIO_0, IOT_GPIO_FUNC_GPIO_10_GPIO);
    IoTGpioSetDir(GPIO_0, IOT_GPIO_DIR_IN);

    IoTGpioInit(GPIO_1);
    IoTGpioSetFunc(GPIO_1, IOT_GPIO_FUNC_GPIO_12_GPIO);
    IoTGpioSetDir(GPIO_1, IOT_GPIO_DIR_OUT);
    IoTGpioSetOutputVal(GPIO_1, IOT_GPIO_VALUE1);
    hi_udelay(20);
    IoTGpioSetOutputVal(GPIO_1, IOT_GPIO_VALUE0);

    while (1) {
        IoTGpioGetInputVal(GPIO_0, &value);
        if ( value == IOT_GPIO_VALUE1 && flag == 0) {
            start_time = hi_get_us();
            flag = 1;
        }
        if (value == IOT_GPIO_VALUE0 && flag == 1) {
            time = hi_get_us() - start_time;
            start_time = 0;
            break;
        }
    }
    distance = time * 0.034 / 2;
    return distance;
}

 
 
static void ExampleTask(void)
{
    IotGpioValue value = IOT_GPIO_VALUE0;
    // IoTGpioInit(11);
    // IoTGpioSetFunc(11, IOT_GPIO_FUNC_GPIO_11_GPIO);
    // IoTGpioSetPull(11,IOT_GPIO_PULL_UP);
    // IoTGpioSetDir(11, IOT_GPIO_DIR_IN);
    
    printf("start test hcsr04\r\n");
    while (1) {
        // IoTGpioGetInputVal(11, &value);
        // if (value == IOT_GPIO_VALUE0) {
            float distance = GetDistance();
            printf("distance is %f\r\n", distance);
            // 
        // }
        osDelay(100);
    }

}


static void ExampleEntry(void)
{
    osThreadAttr_t attr;

    attr.name = "ExampleTask";
    attr.attr_bits = 0U;
    attr.cb_mem = NULL;
    attr.cb_size = 0U;
    attr.stack_mem = NULL;
    attr.stack_size = TASK_STACK_SIZE;
    attr.priority = TASK_PRIO;

    if (osThreadNew((osThreadFunc_t)ExampleTask, NULL, &attr) == NULL) {
        printf("Failed to create ExampleTask!\n");
    }
}

APP_FEATURE_INIT(ExampleEntry);