#include "DOOR.h"
#include "iot_gpio.h"
#include "iot_gpio_ex.h"


#define OUT_GPIO 13
#define LED_SAFE_GPIO 7
#define LED_WARN_GPIO 14
#define BEEP_GPIO 8



void BoardInit(void)
{   
    IoTGpioInit(OUT_GPIO);
    IoTGpioSetFunc(OUT_GPIO, IOT_GPIO_FUNC_GPIO_13_GPIO);
    IoTGpioSetDir(OUT_GPIO, IOT_GPIO_DIR_IN); // 设置GPIO_8为输出模式

    IoTGpioInit(LED_SAFE_GPIO);
    IoTGpioSetFunc(LED_SAFE_GPIO, IOT_GPIO_FUNC_GPIO_7_GPIO);
    IoTGpioSetDir(LED_SAFE_GPIO, IOT_GPIO_DIR_OUT); // 设置为输出模式

    IoTGpioInit(LED_WARN_GPIO);
    IoTGpioSetFunc(LED_WARN_GPIO, IOT_GPIO_FUNC_GPIO_14_GPIO);
    IoTGpioSetDir(LED_WARN_GPIO, IOT_GPIO_DIR_OUT); // 设置为输入模式

    IoTGpioInit(BEEP_GPIO);
    IoTGpioSetFunc(BEEP_GPIO, IOT_GPIO_FUNC_GPIO_8_GPIO);
    IoTGpioSetDir(BEEP_GPIO, IOT_GPIO_DIR_OUT); // 设置为输入模式
}

/***************************************************************
* 函数名称: Door_Read_Data
* 说    明: 读取数据
* 参    数: 无
* 返 回 值: 无
***************************************************************/
uint8_t Door_Read_Data(void)
{
    IotGpioValue temp = {0};
    IoTGpioGetInputVal(OUT_GPIO,&temp);
    return temp;
}

/***************************************************************
 * 函数名称: BeepStatusSet
 * 说    明: Beep状态设置
 * 参    数: status,ENUM枚举的数据
 *									OFF,关
 *									ON,开
 * 返 回 值: 无
 ***************************************************************/
void BeepStatusSet(SwitchStatus status)
{
    if (status == ON) {
        IoTGpioSetOutputVal(BEEP_GPIO, 1); // 设置GPIO_7输出高电平点亮灯
    }
    if (status == OFF) {
        IoTGpioSetOutputVal(BEEP_GPIO, 0); // 设置GPIO_7输出低电平关闭灯
    }
}

/***************************************************************
 * 函数名称: LedWarnStatusSet
 * 说    明: LED_Warn状态设置
 * 参    数: status,ENUM枚举的数据
 *									OFF,关
 *									ON,开
 * 返 回 值: 无
 ***************************************************************/
void LedWarnStatusSet(SwitchStatus status)
{
    if (status == ON) {
        IoTGpioSetOutputVal(LED_WARN_GPIO, 1); // 设置输出高电平点亮灯
    }

    if (status == OFF) {
        IoTGpioSetOutputVal(LED_WARN_GPIO, 0); // 设置输出低电平关闭灯
    }
}
/***************************************************************
 * 函数名称: LedSafeStatusSet
 * 说    明: LED_Safe状态设置
 * 参    数: status,ENUM枚举的数据
 *									OFF,关
 *									ON,开
 * 返 回 值: 无
 ***************************************************************/
void LedSafeStatusSet(SwitchStatus status)
{
    if (status == ON) {
        IoTGpioSetOutputVal(LED_SAFE_GPIO, 1); // 设置输出高电平点亮灯
    }

    if (status == OFF) {
        IoTGpioSetOutputVal(LED_SAFE_GPIO, 0); // 设置输出低电平关闭灯
    }
}
