/*
 * Copyright (c) 2020  Jinan Bosai Network Technology Co., LTD
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "mlx90614.h"
#include "cmsis_os2.h"
#include "ohos_init.h"

#define TASK_STACK_SIZE 1024 * 8
#define TASK_PRIO 25



static void ExampleTask(void)
{

    MLX90614_Init();

    while (1) {
        printf("\r\n Ambient Temp: %0.2f \r\n", MLX90614_Read_TempData(MLX90614_RAM | AMBIENT_TEMP));    // ambient 
        printf("\r\n Object Temp: %0.2f \r\n", MLX90614_Read_TempData(MLX90614_RAM | OBJECT_TEMP));     // object
        
        if(MLX90614_Read_TempData(MLX90614_RAM | OBJECT_TEMP)>32)
        {
            LedSafeStatusSet(OFF);
            LedWarnStatusSet(ON);
            BeepStatusSet(ON);
        }
        else
        {
            LedSafeStatusSet(ON);
            LedWarnStatusSet(OFF);
            BeepStatusSet(OFF);
        }
        sleep(2);
    }
}

static void ExampleEntry(void)
{
    osThreadAttr_t attr;

    attr.name = "ExampleTask";
    attr.attr_bits = 0U;
    attr.cb_mem = NULL;
    attr.cb_size = 0U;
    attr.stack_mem = NULL;
    attr.stack_size = TASK_STACK_SIZE;
    attr.priority = TASK_PRIO;

    if (osThreadNew((osThreadFunc_t)ExampleTask, NULL, &attr) == NULL) {
        printf("Failed to create ExampleTask!\n");
    }
}

APP_FEATURE_INIT(ExampleEntry);