/*
 * Copyright (c) 2020  Jinan Bosai Network Technology Co., Ltd.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <string.h>
#include <unistd.h>

#include "DHT11.h"
#include "BH1750.h"
#include "cmsis_os2.h"
#include "ohos_init.h"


#define TASK_STACK_SIZE 1024 * 8
#define TASK_PRIO 25
uint8_t fan_status;

static void FanTask(void)
{
    while (1)
    {
        if(fan_status == 1)
            FanStatusSet(ON,1);
        else
        {
            FanStatusSet(OFF,0);
            sleep(1);
        }
    }
}

static void ExampleTask(void)
{
    int ret;
    uint8_t dht_temperature;
	uint8_t dht_humidity;
    float Lux;
    // BoardInit();
     //GPIO_0复用为I2C1_SDA
    ret = BoardInit();
    if (ret != 0) {
        printf("E53_SC1 Init failed!\r\n");
        return;
    }
    while (1)
    {
		DHT11_Read_Data(&dht_temperature,&dht_humidity);
		printf("temperature=%d \r\n",dht_temperature);
		printf("humidity=%d %%\r\n",dht_humidity);
        ret = BH1750ReadData(&Lux);
        if (ret != 0) {
            printf("E53_SC1 Read Data failed!\r\n");
            return;
        }
        printf("Lux data:%.2f\r\n", Lux);
        if (Lux < 20) {
            fan_status = 1;
            LightStatusSet(ON);
        } else {
            LightStatusSet(OFF);
            fan_status = 0;
            FanStatusSet(OFF,1);
        }
        sleep(3);
    }
}

static void ExampleEntry(void)
{
    osThreadAttr_t attr;

    attr.name = "ExampleTask";
    attr.attr_bits = 0U;
    attr.cb_mem = NULL;
    attr.cb_size = 0U;
    attr.stack_mem = NULL;
    attr.stack_size = TASK_STACK_SIZE;
    attr.priority = TASK_PRIO;


    if (osThreadNew((osThreadFunc_t)ExampleTask, NULL, &attr) == NULL) {
        printf("Failed to create ExampleTask!\n");
    }
    attr.name = "FanTask";
    if (osThreadNew((osThreadFunc_t)FanTask, NULL, &attr) == NULL) {
        printf("Failed to create FanTask!\n");
    }
}

APP_FEATURE_INIT(ExampleEntry);